@@ -7,15 +7,15 @@ from matplotlib.axes import Axes
 from monaco.mc_plot import plot_hist, plot_2d_scatter
 from monaco.mc_var import InVar, OutVar
 from monaco.mc_enums import PlotOrientation, InVarSpace
-from monaco.helper_functions import empty_list
+from monaco.helper_functions import empty_list, get_list
 from typing import Optional, Iterable
 
 
 def multi_plot(vars        : list[InVar | OutVar],
                cases           : None | int | Iterable[int] = None,
                highlight_cases : None | int | Iterable[int] = empty_list(),
-               rug_plot    : bool   = True,
-               cov_plot    : bool   = True,
+               rug_plot    : bool   = False,
+               cov_plot    : bool   = False,
                cov_p       : None | float | Iterable[float] = None,
                invar_space : InVarSpace | Iterable[InVarSpace] = InVarSpace.NUMS,
                fig         : Figure = None,
@@ -33,7 +33,7 @@ def multi_plot(vars        : list[InVar | OutVar],
         The cases to plot. If None, then all cases are plotted.
     highlight_cases : None | int | Iterable[int], default: []
         The cases to highlight. If [], then no cases are highlighted.
-    rug_plot : bool, default: True
+    rug_plot : bool, default: False
         Whether to plot rug marks.
     cov_plot : bool, default: False
         Whether to plot a covariance ellipse at a certain gaussian percentile
@@ -83,13 +83,13 @@ def multi_plot(vars        : list[InVar | OutVar],
     # Many Variable Plots
     elif len(vars) > 2:
         scalarvars = [var for var in vars if var.isscalar]
-        fig, axs = multi_plot_2d_scatter_grid(vars=scalarvars,
-                                              cases=cases, highlight_cases=highlight_cases,
-                                              rug_plot=rug_plot,
-                                              cov_plot=cov_plot, cov_p=cov_p,
-                                              cumulative=False,
-                                              invar_space=invar_space,
-                                              fig=fig, title=title, plotkwargs=plotkwargs)
+        fig, axs = multi_plot_grid_tri(vars=scalarvars,
+                                       cases=cases, highlight_cases=highlight_cases,
+                                       rug_plot=rug_plot,
+                                       cov_plot=cov_plot, cov_p=cov_p,
+                                       cumulative=False,
+                                       invar_space=invar_space,
+                                       fig=fig, title=title, plotkwargs=plotkwargs)
 
     return fig, axs
 
@@ -99,7 +99,7 @@ def multi_plot_2d_scatter_hist(varx     : InVar | OutVar,
                                vary     : InVar | OutVar,
                                cases           : None | int | Iterable[int] = None,
                                highlight_cases : None | int | Iterable[int] = empty_list(),
-                               rug_plot   : bool   = True,
+                               rug_plot   : bool   = False,
                                cov_plot   : bool   = True,
                                cov_p      : None | float | Iterable[float] = None,
                                cumulative : bool   = False,
@@ -122,7 +122,7 @@ def multi_plot_2d_scatter_hist(varx     : InVar | OutVar,
         The cases to plot. If None, then all cases are plotted.
     highlight_cases : None | int | Iterable[int], default: []
         The cases to highlight. If [], then no cases are highlighted.
-    rug_plot : bool, default: True
+    rug_plot : bool, default: False
         Whether to plot rug marks.
     cov_plot : bool, default: False
         Whether to plot a covariance ellipse at a certain gaussian percentile
@@ -181,22 +181,23 @@ def multi_plot_2d_scatter_hist(varx     : InVar | OutVar,
 
 
 
-def multi_plot_2d_scatter_grid(vars     : list[InVar | OutVar],
-                               cases           : None | int | Iterable[int] = None,
-                               highlight_cases : None | int | Iterable[int] = empty_list(),
-                               rug_plot   : bool   = True,
-                               cov_plot   : bool   = True,
-                               cov_p      : None | float | Iterable[float] = None,
-                               cumulative : bool   = False,
-                               invar_space : InVarSpace | Iterable[InVarSpace] = InVarSpace.NUMS,
-                               fig        : Figure = None,
-                               title      : str    = '',
-                               plotkwargs : dict   = dict(),
-                               ) -> tuple[Figure, tuple[Axes, ...]]:
+def multi_plot_grid_tri(vars     : list[InVar | OutVar],
+                        cases           : None | int | Iterable[int] = None,
+                        highlight_cases : None | int | Iterable[int] = empty_list(),
+                        rug_plot   : bool   = False,
+                        cov_plot   : bool   = False,
+                        cov_p      : None | float | Iterable[float] = None,
+                        cumulative : bool   = False,
+                        invar_space : InVarSpace | Iterable[InVarSpace] = InVarSpace.NUMS,
+                        fig        : Figure = None,
+                        title      : str    = '',
+                        plotkwargs : dict   = dict(),
+                        ) -> tuple[Figure, tuple[Axes, ...]]:
     """
-    Plot multiple variables against each other in a grid. The off-diagonal grid
-    locations show scatterplots of the two corresponding variables. The
-    plots along the diagonal show histograms for the corresponding variables.
+    Plot multiple variables against each other in a triangular grid. The
+    off-diagonal grid locations show scatterplots of the two corresponding
+    variables. The plots along the diagonal show histograms for the
+    corresponding variables.
 
     Parameters
     ----------
@@ -206,7 +207,7 @@ def multi_plot_2d_scatter_grid(vars     : list[InVar | OutVar],
         The cases to plot. If None, then all cases are plotted.
     highlight_cases : None | int | Iterable[int], default: []
         The cases to highlight. If [], then no cases are highlighted.
-    rug_plot : bool, default: True
+    rug_plot : bool, default: False
         Whether to plot rug marks.
     cov_plot : bool, default: False
         Whether to plot a covariance ellipse at a certain gaussian percentile
@@ -235,13 +236,16 @@ def multi_plot_2d_scatter_grid(vars     : list[InVar | OutVar],
     nvars = len(vars)
     axs = fig.subplots(nvars, nvars, sharex='col')
     for i in range(nvars):
-        row_scatter_axs = [ax for k, ax in enumerate(axs[i]) if k != i]
+        row_scatter_axs = [ax for k, ax in enumerate(axs[i]) if k < i]
         for j in range(nvars):
             ax = axs[i][j]
             if i == j:
                 plot_hist(vars[i], cases=cases, highlight_cases=highlight_cases,
                           cumulative=cumulative, rug_plot=False, invar_space=invar_space,
                           ax=ax, title='', plotkwargs=plotkwargs)
+                ax.yaxis.tick_right()
+            elif j > i:
+                fig.delaxes(ax)
             else:
                 ax.get_shared_y_axes().join(*row_scatter_axs)  # Don't link the histogram y axis
                 plot_2d_scatter(vars[j], vars[i],
@@ -249,6 +253,8 @@ def multi_plot_2d_scatter_grid(vars     : list[InVar | OutVar],
                                 rug_plot=rug_plot, cov_plot=cov_plot, cov_p=cov_p,
                                 invar_space=invar_space,
                                 ax=ax, title='', plotkwargs=plotkwargs)
+                if j > 0:
+                    ax.set_yticklabels([])
 
             ax.set_xlabel('')
             ax.set_ylabel('')
@@ -257,7 +263,108 @@ def multi_plot_2d_scatter_grid(vars     : list[InVar | OutVar],
             if i == nvars-1:
                 ax.set_xlabel(vars[j].name)
 
-    plt.suptitle(title)
+    fig.subplots_adjust(wspace=0.075, hspace=0.075)
+    fig.suptitle(title)
+
+    return fig, axs
+
+
+def multi_plot_grid_rect(varsx     : InVar | OutVar | list[InVar | OutVar],
+                         varsy     : InVar | OutVar | list[InVar | OutVar] = None,
+                         cases           : None | int | Iterable[int] = None,
+                         highlight_cases : None | int | Iterable[int] = empty_list(),
+                         rug_plot   : bool   = False,
+                         cov_plot   : bool   = False,
+                         cov_p      : None | float | Iterable[float] = None,
+                         cumulative : bool   = False,
+                         invar_space : InVarSpace | Iterable[InVarSpace] = InVarSpace.NUMS,
+                         fig        : Figure = None,
+                         title      : str    = '',
+                         plotkwargs : dict   = dict(),
+                         ) -> tuple[Figure, tuple[Axes, ...]]:
+    """
+    Plot multiple variables against each other in a rectangual grid. The
+    left column and bottom row show histograms for each variable, and the middle
+    grid locations show the scatter plots between each pari of variables.
+
+    Parameters
+    ----------
+    varsx : monaco.mc_var.InVar | monaco.mc_var.OutVar | list[InVar | OutVar]
+        The variables to plot along the X axis.
+    varsy : monaco.mc_var.InVar | monaco.mc_var.OutVar | list[InVar | OutVar]
+        The variables to plot along the Y axis.
+    cases : None | int | Iterable[int], default: None
+        The cases to plot. If None, then all cases are plotted.
+    highlight_cases : None | int | Iterable[int], default: []
+        The cases to highlight. If [], then no cases are highlighted.
+    rug_plot : bool, default: False
+        Whether to plot rug marks.
+    cov_plot : bool, default: False
+        Whether to plot a covariance ellipse at a certain gaussian percentile
+        level.
+    cov_p : None | float | Iterable[float], default: None
+        The gaussian percentiles for the covariance plot.
+    cumulative : bool, default: False
+        Whether to plot the histograms as cumulative distribution functions.
+    invar_space : monaco.InVarSpace | Iterable[InVarSpace], default: 'nums'
+        The space to plot invars in, either 'nums' or 'pcts'. If an iterable,
+        specifies this individually for each of varx, vary, and varz.
+    fig : matplotlib.figure.Figure, default: None
+        The figure handle to plot in. If None, a new figure is created.
+    title : str, default: ''
+        The figure title.
+
+    Returns
+    -------
+        (fig, axes) : (matplotlib.figure.Figure, (matplotlib.axes.Axes, ...))
+            fig is the figure handle for the plot.
+            axes is a tuple of the axes handles for the plots, starting from
+            the top-left corner and working left-to-right, then top-to-bottom.
+    """
+    fig = handle_fig(fig)
+
+    varsx = get_list(varsx)
+    varsy = get_list(varsy)
+    nvarsx = len(varsx)
+    nvarsy = len(varsy)
+
+    axs = fig.subplots(nvarsy+1, nvarsx+1, sharex='col')
+    for i in range(nvarsy+1):
+        row_scatter_axs = [ax for k, ax in enumerate(axs[i]) if k < nvarsy+1]
+        for j in range(nvarsx+1):
+            ax = axs[i][j]
+            if i == nvarsy and j == 0:
+                fig.delaxes(ax)
+            elif i == nvarsy:
+                plot_hist(varsx[j-1], cases=cases, highlight_cases=highlight_cases,
+                          cumulative=cumulative, rug_plot=False, invar_space=invar_space,
+                          orientation=PlotOrientation.VERTICAL,
+                          ax=ax, title='', plotkwargs=plotkwargs)
+            elif j == 0:
+                plot_hist(varsy[i], cases=cases, highlight_cases=highlight_cases,
+                          cumulative=cumulative, rug_plot=False, invar_space=invar_space,
+                          orientation=PlotOrientation.HORIZONTAL,
+                          ax=ax, title='', plotkwargs=plotkwargs)
+                ax.set_xticklabels([])
+            else:
+                ax.get_shared_y_axes().join(*row_scatter_axs)  # Don't link the histogram y axis
+                plot_2d_scatter(varsx[j-1], varsy[i],
+                                cases=cases, highlight_cases=highlight_cases,
+                                rug_plot=rug_plot, cov_plot=cov_plot, cov_p=cov_p,
+                                invar_space=invar_space,
+                                ax=ax, title='', plotkwargs=plotkwargs)
+            if j > 0:
+                ax.set_yticklabels([])
+
+            ax.set_xlabel('')
+            ax.set_ylabel('')
+            if i < nvarsy and j == 0:
+                ax.set_ylabel(varsy[i].name)
+            if i == nvarsy and j != 0:
+                ax.set_xlabel(varsx[j-1].name)
+
+    fig.subplots_adjust(wspace=0.075, hspace=0.075)
+    fig.suptitle(title)
 
     return fig, axs
 
